@@ -764,11 +764,4 @@ class Firebot:
             }
         }
         message = f"Successfully removed {amount} {currency} to all users in {role} role"
-        self.sendit(data, message)
-
-
-api = Firebot(f"//LAPTOP-54QGG5Q5/Users/baile/AppData/Roaming/",
-                      "http://192.168.1.23:7472/")
-
-cur = api.get_topcurrency("Points", count= 1)
-print(cur)
\ No newline at end of file
+        self.sendit(data, message)
\ No newline at end of file
